==> haskell-modern-uri-0.3.6.1-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-modern-uri.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 modern-uri
version:              0.3.6.1
visibility:           public
id:                   modern-uri-0.3.6.1-BPJiaRKhv3U6osM58jEd4s
key:                  modern-uri-0.3.6.1-BPJiaRKhv3U6osM58jEd4s
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/modern-uri
synopsis:             Modern library for working with URIs
description:          Modern library for working with URIs.
category:             Text
abi:                  bc3808f5ed801087f9ff19bb2ce91ae9
exposed:              True
exposed-modules:      Text.URI Text.URI.Lens Text.URI.QQ
hidden-modules:
    Text.URI.Parser.ByteString Text.URI.Parser.Text
    Text.URI.Parser.Text.Utils Text.URI.Render Text.URI.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/modern-uri-0.3.6.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/modern-uri-0.3.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-modern-uri
hs-libraries:         HSmodern-uri-0.3.6.1-BPJiaRKhv3U6osM58jEd4s
depends:
    QuickCheck-2.14.3-2fwOGp9PorUAao68q5lrRL base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1 deepseq-1.4.6.1
    exceptions-0.10.4 hashable-1.4.3.0-3dqA7o3S1KBIuEdO2YDkYf
    megaparsec-9.5.0-8MD0AbTMoDq3ANXFtJon7o mtl-2.2.2
    profunctors-5.6.2-Ak4NfIHWWTtKZ2x63ZD0Ws
    reflection-2.1.7-1QYIVmmSwPu42Crf4M7Liq
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg template-haskell-2.18.0.0
    text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-modern-uri/html/modern-uri.haddock
haddock-html:         /usr/share/doc/haskell-modern-uri/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-modern-uri-0.3.6.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-modern-uri.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 modern-uri
version:              0.3.6.1
visibility:           public
id:                   modern-uri-0.3.6.1-82WPXSD0iplCdVYmawv09S
key:                  modern-uri-0.3.6.1-82WPXSD0iplCdVYmawv09S
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/modern-uri
synopsis:             Modern library for working with URIs
description:          Modern library for working with URIs.
category:             Text
abi:                  11ef9c48264f11d595e725bc51518e8a
exposed:              True
exposed-modules:      Text.URI Text.URI.Lens Text.URI.QQ
hidden-modules:
    Text.URI.Parser.ByteString Text.URI.Parser.Text
    Text.URI.Parser.Text.Utils Text.URI.Render Text.URI.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/modern-uri-0.3.6.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/modern-uri-0.3.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-modern-uri
hs-libraries:         HSmodern-uri-0.3.6.1-82WPXSD0iplCdVYmawv09S
depends:
    QuickCheck-2.14.3-2FUI0ycZlrbG7BkVMiUKvc base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1 deepseq-1.4.6.1
    exceptions-0.10.4 hashable-1.4.3.0-4gqtyFKn8Wu9OwsZtyYGdt
    megaparsec-9.5.0-7z3AThgMzs3rnIZVIvVtE mtl-2.2.2
    profunctors-5.6.2-874JaSR4cxIIwGWdMN4T7c
    reflection-2.1.7-HemkYmjlWTJAh5UXuGe0A
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg template-haskell-2.18.0.0
    text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-modern-uri/html/modern-uri.haddock
haddock-html:         /usr/share/doc/haskell-modern-uri/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
